.. Chimère documentation master file, created by
   sphinx-quickstart on Wed Feb 15 00:42:28 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Chimère's documentation!
===================================

.. toctree::
   :maxdepth: 2

   install
   upgrade
   configuration
   administration
   import_export
   customisation
